package ru.myitschool.work.ui.profile

import android.os.Bundle
import android.util.Log
import android.view.View
import androidx.appcompat.app.AlertDialog
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import com.squareup.picasso.Picasso
import ru.myitschool.work.R
import ru.myitschool.work.databinding.FragmentUserBinding
import ru.myitschool.work.ui.qr.result.RESPONSE_KEY
import ru.myitschool.work.ui.qr.scan.QrScanDestination
import ru.myitschool.work.utils.collectWithLifecycle
import ru.myitschool.work.utils.visibleOrGone


class UserFragment : Fragment(R.layout.fragment_user) {

    private var _binding: FragmentUserBinding? = null
    private val binding: FragmentUserBinding get() = _binding!!

    private val viewModel by viewModels<UserViewModel> { UserViewModel.Factory }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        _binding = FragmentUserBinding.bind(view)

        val adapter = PassesListAdapter()
        binding.passes.adapter = adapter

        viewModel.state.collectWithLifecycle(this) { state ->
            binding.refresh.isRefreshing = state is UserViewModel.State.Loading
            binding.content.visibleOrGone(state is UserViewModel.State.Show)
            when (state) {
                is UserViewModel.State.Loading -> Unit
                is UserViewModel.State.Show -> {
                    val user = state.userEntity
                    adapter.submitList(state.passes)
                    binding.scan.visibleOrGone(!user.isCardBlocked)
                    binding.findUser.visibleOrGone(user.isAdmin)
                    binding.fullname.text = user.name
                    binding.position.text = user.position
                    binding.lastEntry.text = user.lastVisit
                    Picasso.get().load(user.photoUrl).into(binding.photo)

                }
            }
        }

        binding.refresh.setOnRefreshListener {
            viewModel.onRefresh()
        }

        binding.logout.setOnClickListener {
            AlertDialog.Builder(requireContext())
                .setTitle("Выход")
                .setMessage("Вы уверены, что хотите выйти из аккаунта?")
                .setIcon(android.R.drawable.ic_dialog_alert)
                .setPositiveButton(android.R.string.ok) { _, _ ->
                    viewModel.onLogout()
                    findNavController().navigate(R.id.action_userFragment_to_loginFragment)
                }
                .show()
        }

        binding.findUser.setOnClickListener {
            findNavController().navigate(R.id.action_userFragment_to_adminFragment)
        }

        binding.scan.setOnClickListener {
            findNavController().navigate(R.id.action_userFragment_to_qrScanFragment)
        }

        parentFragmentManager.setFragmentResultListener(
            QrScanDestination.REQUEST_KEY, this
        ) { _, result ->
            parentFragmentManager.setFragmentResult(RESPONSE_KEY, result)
            findNavController().navigate(R.id.action_userFragment_to_qrResultFragment)
        }

    }

    override fun onDestroy() {
        _binding = null
        super.onDestroy()
    }
}