package ru.myitschool.work.ui.qr.result

import android.os.Bundle
import android.view.View
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import ru.myitschool.work.R
import ru.myitschool.work.databinding.FragmentQrResultBinding
import ru.myitschool.work.domain.entities.QrEntity
import ru.myitschool.work.ui.qr.scan.QrScanDestination.getDataIfExist
import ru.myitschool.work.utils.collectWithLifecycle


const val RESPONSE_KEY: String = "response_qr"

class QrResultFragment : Fragment(R.layout.fragment_qr_result) {

    private var _binding: FragmentQrResultBinding? = null
    private val binding: FragmentQrResultBinding get() = _binding!!

    private val viewModel by viewModels<QrResultViewModel> { QrResultViewModel.Factory }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        _binding = FragmentQrResultBinding.bind(view)

        parentFragmentManager.setFragmentResultListener(RESPONSE_KEY, this) { _, result ->
            getDataIfExist(result)?.let { viewModel.setQr(QrEntity(it)) }
            viewModel.update()
        }

        viewModel.state.collectWithLifecycle(this) { state ->
            if (viewModel._qrEntity == null) {
                binding.result.setText(R.string.door_closed)
                binding.close.background =
                    ContextCompat.getDrawable(requireContext(), R.drawable.warn_button)
            }

            when (state) {
                is QrResultViewModel.State.Error -> {
                    binding.result.text = state.message
                    binding.close.background =
                        ContextCompat.getDrawable(requireContext(), R.drawable.warn_button)
                }

                is QrResultViewModel.State.Loading -> Unit
                is QrResultViewModel.State.Show -> {
                    binding.result.setText(R.string.door_opened)
                    binding.close.background =
                        ContextCompat.getDrawable(requireContext(), R.drawable.main_button)
                }
            }
        }

        binding.close.setOnClickListener {
            findNavController().navigate(R.id.action_qrResultFragment_to_userFragment)
        }
    }

    override fun onDestroy() {
        _binding = null
        super.onDestroy()
    }
}