package ru.myitschool.work.ui.qr.result

import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.viewModelScope
import androidx.lifecycle.viewmodel.CreationExtras
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import ru.myitschool.work.data.network.QrNetworkDataSource
import ru.myitschool.work.data.QrRepositoryImpl
import ru.myitschool.work.data.local.CredentialsLocalDataSource
import ru.myitschool.work.domain.entities.QrEntity
import ru.myitschool.work.domain.qr.PushQrUseCase

class QrResultViewModel(
    private val pushQrUseCase: PushQrUseCase
) : ViewModel() {

    private val _state = MutableStateFlow<State>(State.Loading)
    val state = _state.asStateFlow()

    var _qrEntity: QrEntity? = null
    private val qrEntity: QrEntity get() = _qrEntity!!

    fun setQr(qrEntity: QrEntity) {
        _qrEntity = qrEntity
    }

    fun update() {
        viewModelScope.launch {
            pushQrUseCase(qrEntity).fold(
                onSuccess = { _state.emit(State.Show) },
                onFailure = { _state.emit(State.Error(it.message.toString())) }
            )
        }
    }

    sealed interface State {
        data object Loading : State
        data object Show : State
        data class Error(val message: String) : State
    }

    companion object {
        val Factory: ViewModelProvider.Factory = object : ViewModelProvider.Factory {
            @Suppress("UNCHECKED_CAST")
            override fun <T : ViewModel> create(modelClass: Class<T>, extras: CreationExtras): T {
                return QrResultViewModel(
                    pushQrUseCase = PushQrUseCase(
                        repository = QrRepositoryImpl(
                            networkDataSource = QrNetworkDataSource,
                            credentialsLocalDataSource = CredentialsLocalDataSource.getInstance()
                        )
                    )
                ) as T
            }
        }
    }
}